<!--
SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>

SPDX-License-Identifier: CC-BY-SA-4.0
-->

DHTMLX Skins
============

This folder contains skins for DHTMLX.

Style all skins
---------------

If you like to add a style that is present when all skins are present,
please add it to `style.css`.

Adding a new Skin
-----------------

Sometimes it might be enough to just add some CSS to your calendar.
If you like to add a new skin

1. Put the new skin into this folder
2. Add the skin to the index page.
3. Add the skin name to the translations.
4. Make sure all files are loaded by the browser.

Further Reading
---------------

- [DHTMLX skins](https://docs.dhtmlx.com/scheduler/skins.html)


